@@ -3,7 +3,7 @@ simulate.mchain <- function(object, nsim=1, seed=NULL, ...){
     if (!is.null(seed)) set.seed(seed)
     m <- ncol(object$Pi)
     #------------------------
-    if (sum(object$delta)!=1) stop("Invalid delta")
+    if (!isTRUE(all.equal(sum(object$delta), 1))) stop("Invalid delta")
     if (any(object$delta==1))
         initial <- (1:m)[as.logical(object$delta)]
     else
