@@ -1,5 +1,6 @@
 #    Compare mmglm0 and mmglm1
 #    Gaussian with identity link function
+#    R CMD BATCH --no-save mmglm0-mmglm1-gaussian.R mmglm0-mmglm1-gaussian.Rout.save
 
 library(HiddenMarkov)
 
@@ -25,7 +26,7 @@ x0 <- mmglm0(NULL, Pi, delta, family="gaussian", link="identity",
 
 x0 <- simulate(x0, nsim=5000, seed=10)
 
-x0 <- BaumWelch(x0)
+x0 <- BaumWelch(x0, bwcontrol(prt=FALSE))
 
 print(summary(x0))
 
@@ -38,7 +39,7 @@ Xdesign <- model.matrix(glmformula, data=x0$x)
 
 x1 <- mmglm1(x0$x$y, Pi, delta, glmfamily, beta, Xdesign, sigma=sd, msg=FALSE)
 
-x1 <- BaumWelch(x1)
+x1 <- BaumWelch(x1, bwcontrol(prt=FALSE))
 
 print(summary(x1))
 
